@@ -20,40 +20,40 @@
 #   egc_adf_qtab <- egc_quantile_table("adf")
 egc_adf_qtab <- structure(list(quantile = c(NA, 1e-04, 0.01, 0.025, 0.05, 0.1, 
 0.2, 0.5, 0.8, 0.9, 0.95, 0.975, 0.99, 0.999, 0.9999), `25` = c(25, 
--6.82250219242378, -4.46661052588325, -4.00475599937948, -3.66220748383464, 
--3.28216656346919, -2.86590314679678, -2.16913368045838, -1.50075662675211, 
--1.09869456855476, -0.707376464101655, -0.332468251332744, 0.107652360327496, 
-1.00709564081704, 1.91846330041794), `50` = c(50, -5.90031369372017, 
--4.24974811950817, -3.89196306810039, -3.59026093887678, -3.25586397493684, 
--2.89293708645451, -2.25351483865642, -1.63274187325847, -1.24282567813493, 
--0.886990250678287, -0.557740434091227, -0.142320559436172, 0.758470475525642, 
-1.32529566972668), `100` = c(100, -5.35423335387404, -4.16243361491686, 
--3.83602412929703, -3.55493732070356, -3.25821675368631, -2.90647707985012, 
--2.28872436582548, -1.68389591712136, -1.3247114283679, -0.98259702440316, 
--0.661702171343778, -0.272200443099633, 0.571558557411948, 1.26134849462017
-), `250` = c(250, -5.32169658333163, -4.11068853767939, -3.81940000984988, 
--3.56119634309084, -3.26424779449212, -2.92597765126574, -2.31492857507422, 
--1.72444096801193, -1.38783722528013, -1.07095161034388, -0.779374411552248, 
--0.423320784086461, 0.40567187496224, 1.024742338797), `500` = c(500, 
--5.24438771322382, -4.1046678117876, -3.80394774580977, -3.55339441563194, 
--3.27695767692977, -2.94440908560947, -2.33938602148616, -1.74581654896007, 
--1.4132857939648, -1.1169379497244, -0.830141162033237, -0.465778748069809, 
-0.385094864798775, 0.964119035978792), `750` = c(750, -5.25983185847632, 
--4.12933224960047, -3.83970653883534, -3.57291092601257, -3.28898463982481, 
--2.94582095357127, -2.34103700922763, -1.74956185549751, -1.41911350392386, 
--1.11329138497356, -0.837265137997805, -0.501527433716493, 0.207037398489134, 
-0.853874254435031), `1000` = c(1000, -5.31863097152306, -4.14687976118349, 
--3.82721765117813, -3.57658709189777, -3.29530031385029, -2.95266445456483, 
--2.34541912903951, -1.74677020913492, -1.4303717434034, -1.13415927195089, 
--0.855675386839316, -0.517178696611797, 0.194504972589135, 0.953935200801842
-), `1250` = c(1250, -5.34381676607384, -4.10022572980013, -3.82008827402893, 
--3.57080284633046, -3.29051306783958, -2.95763482283479, -2.34815790334682, 
--1.75337613742464, -1.43607541465393, -1.13530579667183, -0.867651555662172, 
--0.52451703983386, 0.163175391030527, 0.79066390181105), `2500` = c(2500, 
--5.48263498988541, -4.10626409894068, -3.81637022589474, -3.57405918222471, 
--3.28863948464811, -2.96305857836569, -2.35770540383653, -1.76998261937848, 
--1.45053398476124, -1.1535106961009, -0.87911223343783, -0.526093269639521, 
-0.271375890964498, 0.822501041543799)), .Names = c("quantile", 
+-5.80600065964837, -3.96967149868031, -3.57824796147135, -3.25972771321035, 
+-2.91769544207541, -2.53653941727733, -1.87885900097153, -1.23635907388638, 
+-0.848888902162473, -0.497965156016583, -0.226150888703246, 0.0919944227492717, 
+0.715514345109964, 1.13746830802583), `50` = c(50, -5.24240810499968, 
+-3.88436984764926, -3.51841394814949, -3.22772975052556, -2.93249574413191, 
+-2.57511899641644, -1.93534867641615, -1.29792146450943, -0.897388203762267, 
+-0.546047631311591, -0.247930007718635, 0.0923702276922401, 0.789911712445357, 
+1.1349646405655), `100` = c(100, -5.18614553477463, -3.82028178996715, 
+-3.50744267955286, -3.24705549993499, -2.94175070261879, -2.59348547506723, 
+-1.95834721747418, -1.32553379739761, -0.93443865659125, -0.566504307577409, 
+-0.242061094013615, 0.111373176009, 0.867741882893275, 1.59691079410486
+), `250` = c(250, -5.05252931421373, -3.84060323769614, -3.52272563987771, 
+-3.27285179097311, -2.98843125307626, -2.63978528664028, -1.99656573545568, 
+-1.34914752339741, -0.955671079430595, -0.59536217425783, -0.252621338347237, 
+0.0899987781539045, 0.969480195222591, 1.67437762726293), `500` = c(500, 
+-4.85128032044083, -3.85833025117506, -3.55728995027321, -3.30071683971755, 
+-3.01071194742856, -2.6609928745281, -2.02202638716769, -1.37661045477456, 
+-0.98234250690942, -0.619068716843792, -0.27371347078372, 0.13315155687368, 
+0.865369556696318, 1.52205842706039), `750` = c(750, -4.83835340698721, 
+-3.83881344355717, -3.54242745598571, -3.29704259642577, -3.01323322264831, 
+-2.66483797384133, -2.02994011861584, -1.37999100147531, -0.999328031721282, 
+-0.621031412365913, -0.292480170395573, 0.0800960217442984, 0.897234407421888, 
+1.50745527599032), `1000` = c(1000, -4.97941096009447, -3.85485811203703, 
+-3.5541966311385, -3.30433478199755, -3.01909801272636, -2.6777972051341, 
+-2.03200019463226, -1.38431436486989, -0.996001675456806, -0.634806184644324, 
+-0.300563520344664, 0.0969685582020578, 0.970683881879207, 1.48835101741877
+), `1250` = c(1250, -5.0796703725486, -3.87636404563864, -3.5691833688799, 
+-3.31236204044198, -3.01659802560495, -2.67464862923784, -2.0338504140494, 
+-1.38393075567463, -0.992858354334467, -0.612689283453555, -0.277705535093365, 
+0.12234390933653, 0.835475797246308, 1.51161252736622), `2500` = c(2500, 
+-4.93123154657244, -3.87361135465214, -3.57724739925402, -3.31986317733849, 
+-3.0239955384488, -2.68391352548266, -2.04130703323206, -1.38983251418602, 
+-1.00504861561616, -0.628990737143362, -0.303520699416405, 0.104495525816474, 
+0.929299065343716, 1.59447329546194)), .Names = c("quantile", 
 "25", "50", "100", "250", "500", "750", "1000", "1250", "2500"
 ), row.names = c("", "0.01%", "1%", "2.5%", "5%", "10%", "20%", 
 "50%", "80%", "90%", "95%", "97.5%", "99%", "99.9%", "99.99%"
@@ -63,40 +63,40 @@ egc_adf_qtab <- structure(list(quantile = c(NA, 1e-04, 0.01, 0.025, 0.05, 0.1,
 #  egc_pp_qtab <- egc_quantile_table("pp")
 egc_pp_qtab <- structure(list(quantile = c(NA, 1e-04, 0.01, 0.025, 0.05, 0.1, 
 0.2, 0.5, 0.8, 0.9, 0.95, 0.975, 0.99, 0.999, 0.9999), `25` = c(25, 
--31.7483317260169, -22.4259942143006, -20.0891471142396, -18.2228875467491, 
--16.2900282564813, -14.0290911430216, -9.98925085234759, -6.41035091322298, 
--4.70746367352161, -3.3545521937257, -2.20449603515498, -1.00333103816288, 
-1.76278039927971, 4.36583517280819), `50` = c(50, -39.8204238377295, 
--27.3302057249438, -24.0799945780677, -21.6516578455852, -19.0697266343428, 
--16.0045124615486, -10.8304998604655, -6.71114279673032, -4.95283812295386, 
--3.58773892769175, -2.53250950500307, -1.33650377090982, 0.849883907175838, 
-2.87260613428669), `100` = c(100, -44.7864231243006, -30.638876291843, 
--27.024277485246, -23.9091867343539, -20.5387166669581, -16.8078987859275, 
--11.0424387103879, -6.67592689143081, -4.87340746087305, -3.59267645284015, 
--2.54631521611987, -1.48163658965051, 0.654286425103889, 2.45308734981177
-), `250` = c(250, -52.3813922346657, -32.7257688261613, -28.2514965979308, 
--24.7843612597892, -21.193356294857, -17.2952885039841, -11.1154112538718, 
--6.73989823169638, -4.92626694694195, -3.64195105982085, -2.63349537765853, 
--1.5885165993875, 0.382882246362119, 1.72727581682196), `500` = c(500, 
--52.4313893755687, -32.6520179408335, -28.2585583397316, -24.6814868556535, 
--21.0347391176349, -17.0942430028448, -10.9731074618946, -6.60661454001619, 
--4.87079674365988, -3.66571472079707, -2.63806781366398, -1.60795720185688, 
-0.474461376434679, 1.7231901818137), `750` = c(750, -51.7027126407095, 
--33.1620272058072, -28.3591110876713, -24.7988360099677, -21.0460064345614, 
--16.9322970862411, -10.8738480586768, -6.58818302982247, -4.83041867050955, 
--3.59149192513659, -2.61647545777101, -1.51292326090877, 0.644757851844955, 
-2.48866850121809), `1000` = c(1000, -54.4030728852552, -32.712384272494, 
--28.3999735902766, -24.968962543997, -21.1185117281465, -17.0447483918261, 
--10.8895595879606, -6.55758523630802, -4.80567543136177, -3.56763756304767, 
--2.57884471059726, -1.42233865489255, 0.474594978280921, 2.06862897693011
-), `1250` = c(1250, -58.0986707297663, -33.0461480510437, -28.5125014119486, 
--24.8559511482087, -21.1071169863818, -17.0973790437607, -10.9683521659909, 
--6.57573587613659, -4.8495786821022, -3.63118603392207, -2.66296753810603, 
--1.59045686730992, 0.408910258628224, 2.46146883303944), `2500` = c(2500, 
--53.6421196025365, -32.5390612193389, -27.8551479695678, -24.3774680094461, 
--20.7899114890461, -16.9111234650402, -10.9055637754689, -6.60540322577147, 
--4.8653314977783, -3.60531304485548, -2.63282041695351, -1.50078156941867, 
-0.592412700964834, 2.89693019375655)), .Names = c("quantile", 
+-29.7565417246292, -20.3971994666692, -18.146559481418, -16.3011085149503, 
+-14.2391155820147, -11.8150963786742, -7.5899592780893, -4.15096635903013, 
+-2.60094473871757, -1.43339001874047, -0.467039141445771, 0.570199459331984, 
+2.57940275214657, 4.84025830039889), `50` = c(50, -37.2231274542497, 
+-24.4557731741679, -21.3929138388286, -18.8614871870361, -16.1389752507269, 
+-13.0795192863213, -8.04644566917229, -4.29658782369691, -2.68013964887425, 
+-1.48502292300255, -0.584507066376888, 0.37615470388534, 2.40978417480265, 
+4.3200178128311), `100` = c(100, -43.426742478486, -27.5974048358845, 
+-23.6031859946393, -20.4580160947768, -17.1986747077983, -13.6429760820469, 
+-8.12217622614848, -4.22777954156694, -2.66476562368888, -1.54545744092887, 
+-0.636175690120419, 0.261961612457279, 2.12993106273921, 3.56562198394928
+), `250` = c(250, -47.0690681964392, -29.0960896400917, -24.4928331552785, 
+-21.1394469521393, -17.5358643357831, -13.7600996041061, -8.14408729814865, 
+-4.25496422851803, -2.68238752031604, -1.49700685184211, -0.618656815748225, 
+0.289530850749153, 1.96587622968128, 3.16868565102177), `500` = c(500, 
+-51.205031814866, -28.6470594302683, -24.4050407990774, -21.002428033627, 
+-17.4392919303947, -13.6870811851613, -8.05915371009938, -4.1573647915354, 
+-2.59945753801057, -1.49248336310081, -0.686908685958931, 0.158466529052688, 
+1.91231921279196, 3.44605376774065), `750` = c(750, -50.5572979664773, 
+-29.0262823972601, -24.6390828311317, -21.0567367643718, -17.4234244154485, 
+-13.559135320141, -8.00806944056452, -4.14335083605078, -2.62965842402231, 
+-1.52762518846525, -0.692309593470999, 0.164594069455772, 1.84175773730567, 
+3.26339389208958), `1000` = c(1000, -51.0721393168863, -28.9701152727192, 
+-24.499116452129, -20.9693265964951, -17.3041276025917, -13.5313579759124, 
+-7.98874954375296, -4.16108848474232, -2.63667336022509, -1.57321498718066, 
+-0.727235377853383, 0.149961637320794, 1.82950678217979, 3.58839310935961
+), `1250` = c(1250, -47.0274336884959, -28.6533901782375, -24.0324308135337, 
+-20.7516904573044, -17.2676130652863, -13.5632485477366, -8.02973231588857, 
+-4.16297729023449, -2.65204125672226, -1.54778453385605, -0.656865646170381, 
+0.224883510382165, 1.98145276951501, 3.13000464851758), `2500` = c(2500, 
+-47.7056243655114, -28.2578110834848, -23.9980052350113, -20.6534631941346, 
+-17.2047997356392, -13.5207335338673, -7.957478348813, -4.14981750150314, 
+-2.58643765337459, -1.5149841942779, -0.661445201665475, 0.207478441219318, 
+1.73413672925087, 2.96418512944668)), .Names = c("quantile", 
 "25", "50", "100", "250", "500", "750", "1000", "1250", "2500"
 ), row.names = c("", "0.01%", "1%", "2.5%", "5%", "10%", "20%", 
 "50%", "80%", "90%", "95%", "97.5%", "99%", "99.9%", "99.99%"
@@ -106,45 +106,45 @@ egc_pp_qtab <- structure(list(quantile = c(NA, 1e-04, 0.01, 0.025, 0.05, 0.1,
 #  egc_pgff_qtab <- egc_quantile_table("pgff")
 egc_pgff_qtab <- structure(list(quantile = c(NA, 1e-04, 0.01, 0.025, 0.05, 0.1, 
 0.2, 0.5, 0.8, 0.9, 0.95, 0.975, 0.99, 0.999, 0.9999), `25` = c(25, 
--0.336625831999346, 0.0341437189994142, 0.143854756626506, 0.227942822537199, 
-0.321875762327391, 0.430157943286197, 0.616450377657225, 0.762759885088315, 
-0.82361806179326, 0.866940512284584, 0.899155615642256, 0.934900153650464, 
-1.00246211010138, 1.05047797561818), `50` = c(50, 0.220627836953644, 
-0.448634437995673, 0.514235633116768, 0.571095688677306, 0.632523754087507, 
-0.697606185429773, 0.803745405221187, 0.883213445856658, 0.915783884604886, 
-0.938039550199234, 0.957013147125422, 0.975923560598361, 1.01644861773643, 
-1.04196578449547), `100` = c(100, 0.541652148126685, 0.712994671815014, 
-0.747472775368399, 0.777222175184613, 0.810287530989747, 0.845281726392217, 
-0.900971180378913, 0.942387342535367, 0.959658313907702, 0.971236226780725, 
-0.980263097643523, 0.990058680715472, 1.00772162129372, 1.02230585650179
-), `250` = c(250, 0.796887373191436, 0.87644234791977, 0.89398291812434, 
-0.907551318142438, 0.921946440048468, 0.936960981640209, 0.960197179275122, 
-0.977145020492887, 0.984113175240602, 0.989014265711227, 0.992648985719689, 
-0.996589560970954, 1.00422289236937, 1.00981839336385), `500` = c(500, 
-0.906471394939692, 0.938443130778873, 0.947340862521741, 0.953973549191814, 
-0.961015371233118, 0.968651861560137, 0.980224315770123, 0.988669425830378, 
-0.991983402705577, 0.994422930741069, 0.996277428012133, 0.998371861509028, 
-1.00210286323482, 1.00474384238835), `750` = c(750, 0.929012686308371, 
-0.958019758613622, 0.96424798196568, 0.968767071025123, 0.973765639015405, 
-0.978963328796586, 0.986769637760877, 0.992495831119869, 0.994822100137963, 
-0.996421963380021, 0.997694650337578, 0.999024753535889, 1.00178096292395, 
-1.00333529846727), `1000` = c(1000, 0.949176685091427, 0.969203355354484, 
-0.973381143537786, 0.976701237235953, 0.980345880136921, 0.984190946880614, 
-0.990107914093208, 0.994344287184784, 0.996067492560003, 0.997292230446198, 
-0.998227124217666, 0.999197584772469, 1.00094716404021, 1.00270750718348
-), `1250` = c(1250, 0.960643156183032, 0.975146939684992, 0.978682825560059, 
-0.981431908867788, 0.984285583607903, 0.987292545812951, 0.992055628457898, 
-0.995450138647364, 0.996810989623488, 0.99777743131819, 0.998559289716415, 
-0.999300771753356, 1.00098023261994, 1.00232131446558), `2500` = c(2500, 
-0.979239143080471, 0.987594556555884, 0.989307688819376, 0.990671712084724, 
-0.992159172127179, 0.993692063156018, 0.996040818179021, 0.997734558408831, 
-0.998422620884948, 0.998914003067803, 0.999291096260776, 0.999692009809386, 
-1.00042127303711, 1.00133189611659)), .Names = c("quantile", 
+-0.231553821881206, 0.142707930240386, 0.248133260656542, 0.333917931689774, 
+0.428121640033571, 0.539945782620781, 0.723771557722711, 0.864332597229699, 
+0.922105249101673, 0.963987601206701, 0.996514536929339, 1.02970707350455, 
+1.10265843354382, 1.1684196848773), `50` = c(50, 0.172811744068844, 
+0.523681965900934, 0.586787791731764, 0.640475243182477, 0.698272283692989, 
+0.763003427158865, 0.861510838608303, 0.934865539270229, 0.963988752897878, 
+0.983684298255712, 0.999107902125492, 1.01523872341966, 1.04887589032764, 
+1.08320927058697), `100` = c(100, 0.58393295331061, 0.747302308926479, 
+0.786594503536844, 0.814706946790915, 0.844627757777947, 0.878151159116796, 
+0.930456653782436, 0.967744096406227, 0.982277425352853, 0.992439536130561, 
+0.999948043879276, 1.00854567758384, 1.02455735085789, 1.03589000947898
+), `250` = c(250, 0.820931819498695, 0.893121918045134, 0.9100444253408, 
+0.922701510027215, 0.936176560408352, 0.950630316233532, 0.971938078796866, 
+0.987249212798609, 0.993316215891717, 0.997302849731884, 1.00026049554445, 
+1.00339170281377, 1.00986200038529, 1.01497502980754), `500` = c(500, 
+0.915260264269203, 0.947660316795335, 0.955120881224063, 0.9615512652387, 
+0.968212673123382, 0.975333878457326, 0.986218358977486, 0.993749755656947, 
+0.996700016813508, 0.998651986392834, 1.00022742264255, 1.00174462894202, 
+1.00503195091248, 1.00869804701151), `750` = c(750, 0.939511376775531, 
+0.964242019206539, 0.969609009891871, 0.974159154779863, 0.978638973401466, 
+0.983479379364544, 0.99068408949163, 0.995796764989488, 0.997756641711029, 
+0.999151670945693, 1.00012854429786, 1.00115905482996, 1.00333079120998, 
+1.00461694750751), `1000` = c(1000, 0.952901846335396, 0.972960770846218, 
+0.977387781442881, 0.980456839686105, 0.983879665729278, 0.987602057811466, 
+0.9930813790635, 0.996847012417422, 0.998291609862028, 0.999314605853998, 
+1.00007633788893, 1.00083212864199, 1.00248963474574, 1.0036755295172
+), `1250` = c(1250, 0.963783393138941, 0.978506759104274, 0.981788753156713, 
+0.984371043883735, 0.9872049444274, 0.990088040796763, 0.994415785666173, 
+0.997452177824305, 0.998650014908854, 0.999454178064819, 1.00007265964321, 
+1.00070857738882, 1.00193592290277, 1.00293182022315), `2500` = c(2500, 
+0.982585320556602, 0.989012853244208, 0.990724098334862, 0.992056016938316, 
+0.993504460846469, 0.995006847754035, 0.997207718401152, 0.998716056355613, 
+0.999321415287837, 0.999730791683232, 1.00004377282568, 1.00037315158441, 
+1.00102596100525, 1.00166334013542)), .Names = c("quantile", 
 "25", "50", "100", "250", "500", "750", "1000", "1250", "2500"
 ), row.names = c("", "0.01%", "1%", "2.5%", "5%", "10%", "20%", 
 "50%", "80%", "90%", "95%", "97.5%", "99%", "99.9%", "99.99%"
 ), class = "data.frame")
-
+  
 # The following table was generated using the call
 #  egc_joe_qtab <- egc_quantile_table("jo-e")
 egc_joe_qtab <- structure(list(quantile = c(NA, 1e-04, 0.01, 0.025, 0.05, 0.1, 
@@ -408,40 +408,40 @@ egc_bvr_qtab <- structure(list(quantile = c(NA, 1e-04, 0.01, 0.025, 0.05, 0.1,
 #  egc_hurst_qtab <- egc_quantile_table("hurst")
 egc_hurst_qtab <- structure(list(quantile = c(NA, 1e-04, 0.01, 0.025, 0.05, 0.1, 
 0.2, 0.5, 0.8, 0.9, 0.95, 0.975, 0.99, 0.999, 0.9999), `25` = c(25, 
--9.63218513210034, -4.80494350822017, -3.7671534658725, -2.85277130883269, 
--1.83692531355463, -0.752569171726627, 0.604000750059967, 1.35768448858258, 
-1.81882122386621, 2.33272216406319, 2.91221210511881, 3.82876761201107, 
-7.01862426321936, 9.1398433953275), `50` = c(50, -1.9050924494951, 
--0.852513667442171, -0.570085633331304, -0.313161675091895, -0.0383113213022736, 
-0.285313459696212, 0.74243741102064, 0.974872661817781, 1.04321185041397, 
-1.08277705983682, 1.10858767296937, 1.13290665273223, 1.16840006853446, 
-1.19703629775581), `100` = c(100, -0.542341332261871, -0.000460799096853752, 
-0.138306958496461, 0.264338161116628, 0.397567270435087, 0.558043818507171, 
-0.812233608011752, 0.955234695370254, 1.00004004939875, 1.02613047521966, 
-1.04325821078398, 1.05862619690549, 1.07567022398738, 1.08150747353608
-), `250` = c(250, 0.0364467517721989, 0.36709342279675, 0.455844295660924, 
-0.529898175109903, 0.611772154136742, 0.706905728013722, 0.863899663533525, 
-0.961768656905356, 0.99514837605235, 1.01624853292206, 1.02924512646648, 
-1.04045633743049, 1.05451260940423, 1.05965663724796), `500` = c(500, 
-0.326156118737103, 0.543642758431625, 0.607657260251456, 0.661018050941538, 
-0.719786876344008, 0.787840979044478, 0.898654647603, 0.969857607372171, 
-0.994498525078497, 1.00926184204734, 1.01925987211215, 1.02802788622387, 
-1.03855548305486, 1.04346392193489), `750` = c(750, 0.379205027306303, 
-0.585209203892, 0.64438304015065, 0.694344443824018, 0.746016024794462, 
-0.80630119440741, 0.906517472215935, 0.972978852837563, 0.995022730726075, 
-1.008816347688, 1.01855284526596, 1.02637153691943, 1.03610859046259, 
-1.04086016968425), `1000` = c(1000, 0.426771191683228, 0.641826688088124, 
-0.693710039681907, 0.734606999492946, 0.780993517987521, 0.833751313940063, 
-0.919984211407626, 0.977806741856446, 0.997738239061993, 1.01057452818018, 
-1.01900471092174, 1.02607821865229, 1.03519697770899, 1.03896606650759
-), `1250` = c(1250, 0.575494248671508, 0.735200890947932, 0.776637758839186, 
-0.807213631869289, 0.843026054376433, 0.881278523914099, 0.94235670701181, 
-0.983235898640339, 0.998355191302432, 1.00808253560767, 1.01501108261563, 
-1.02068424207231, 1.02828229575173, 1.03126979783162), `2500` = c(2500, 
-0.789099270452659, 0.881814408383096, 0.900764494668801, 0.915952511467294, 
-0.931816490422547, 0.948733872894772, 0.974297337060417, 0.99181834977911, 
-0.998538124195272, 1.00277391299618, 1.00563617512021, 1.00833897419218, 
-1.01204733049964, 1.01345263549346)), .Names = c("quantile", 
+-0.0857104154562339, 0.133210430518201, 0.21757158740498, 0.302075666405815, 
+0.412288002210507, 0.553737145487023, 0.791999850979961, 0.942408563459437, 
+1.03752728028492, 1.12334551390639, 1.199364751987, 1.28935644406156, 
+1.4788624374248, 1.60281934898386), `50` = c(50, -0.210510546641782, 
+0.148521159926177, 0.236754966586507, 0.323062917034732, 0.440561238949842, 
+0.594449346643995, 0.84533338685408, 1.00872532552355, 1.11525381376523, 
+1.21124630034875, 1.30240701508315, 1.40066986434104, 1.62933879134307, 
+1.8094532095276), `100` = c(100, 0.608421115688707, 0.669202684672745, 
+0.686948091874949, 0.700910235690267, 0.715981989608048, 0.732675795425451, 
+0.760742665529899, 0.781868065454202, 0.789995593503324, 0.795612443670174, 
+0.79985565918484, 0.803871575777497, 0.81053430524587, 0.815683684905914
+), `250` = c(250, 0.163269417202177, 0.468343963677446, 0.551403486545482, 
+0.621721912274676, 0.701300434805828, 0.791575778983888, 0.943450340354443, 
+1.08072919858757, 1.15474890396131, 1.22024784792747, 1.27890268009899, 
+1.34897113478298, 1.50453730320009, 1.62350434114705), `500` = c(500, 
+0.559821127511552, 0.725366407087795, 0.769498711209786, 0.807570807014315, 
+0.84517688925953, 0.889458303519949, 0.962545489649822, 1.01986609022312, 
+1.0447836625327, 1.06412850568638, 1.08008137635462, 1.09924572004341, 
+1.13485895275615, 1.16740085470259), `750` = c(750, 0.613233960522025, 
+0.768266005282359, 0.805138052711843, 0.836850174698671, 0.870473987153841, 
+0.90751086837418, 0.969648390381694, 1.02048326095553, 1.04257998217263, 
+1.06035119480173, 1.0749212161725, 1.09030322468911, 1.12030671140103, 
+1.14546764647775), `1000` = c(1000, 0.713557916770165, 0.817283421433091, 
+0.84735474432992, 0.870552278042612, 0.895823505927616, 0.924013441406549, 
+0.972003562463966, 1.01082965461448, 1.02756833257899, 1.04009340082773, 
+1.04991743010241, 1.06078782385471, 1.08116709724364, 1.10024285919318
+), `1250` = c(1250, 0.727861621992402, 0.837966899914253, 0.864397997075103, 
+0.885051362719385, 0.907783875060897, 0.933022641336332, 0.974397559319962, 
+1.00754132228889, 1.02207876108799, 1.03280811634587, 1.04144166798579, 
+1.05119068751227, 1.07004005063871, 1.08337318531449), `2500` = c(2500, 
+0.8270940813197, 0.889562819032396, 0.906227552056674, 0.920370911743679, 
+0.935778423042475, 0.952502655811722, 0.979690819213283, 1.00138535875713, 
+1.01113849483358, 1.01809429851473, 1.02371056339248, 1.02945727068189, 
+1.04114161876617, 1.04932093345531)), .Names = c("quantile", 
 "25", "50", "100", "250", "500", "750", "1000", "1250", "2500"
 ), row.names = c("", "0.01%", "1%", "2.5%", "5%", "10%", "20%", 
 "50%", "80%", "90%", "95%", "97.5%", "99%", "99.9%", "99.99%"
